import axios from 'axios';
import qs from 'qs';
import { Message } from 'element-ui';
import { origin } from '@/config/index.js';

axios.defaults.baseURL = origin;

const request = (opt, params) => {
  params = Object.assign({}, params);
  opt = Object.assign({}, opt);
  let requestConfig = {
    // 请求路径
    url: '',
    params: '',
    data: '',
    // 请求type
    method: 'get',
    // request body 是否使用 formData格式
    useFormData: false,
    // response 是否使用 code === '0000' 验证
    useIntercept: true,
    // 设置headers
    headers: {}
  };
  requestConfig = Object.assign(requestConfig, opt);
  if (requestConfig.useFormData) params = qs.stringify(params);
  switch (requestConfig.method.toLowerCase())  {
    case 'get':
      requestConfig.params = params;
      break;
    case 'post':
      requestConfig.data = qs.stringify(params);
      break;
    default:
      requestConfig.data = params;
      break;
  }
  return new Promise((resolve, reject) => {
    axios(requestConfig).then(res => {
      let resp = res.data;
      if (resp.errorCode != 0) {
        Message({
          message: resp.message || '未知错误',
          type: 'warning'
        });
        return reject(resp);
      }
      resolve(resp);
    }).catch(error => {
      let response = error.response || {};
      let data = response.data || {};
      Message({
        message: data.message || '网络连接异常',
        type: 'warning'
      });
      reject(error);
    });
  });
};

export { axios, request };
